@@ -1,6 +1,6 @@
 import copy
 import time
-
+from prettytable import PrettyTable
 from pocsuite3.lib.core.common import data_to_stdout, desensitization
 from pocsuite3.lib.core.data import conf, cmd_line_options
 from pocsuite3.lib.core.data import kb
@@ -12,7 +12,6 @@ from pocsuite3.lib.core.settings import CMD_PARSE_WHITELIST
 from pocsuite3.lib.core.threads import run_threads
 from pocsuite3.modules.listener import handle_listener_connection
 from pocsuite3.modules.listener.reverse_tcp import handle_listener_connection_for_console
-from pocsuite3.thirdparty.prettytable.prettytable import PrettyTable
 
 
 def runtime_check():
@@ -98,8 +97,8 @@ def task_run():
         if conf.pcap:
             # start capture flow
             import urllib
-            from pocsuite3.thirdparty.scapy.scapy_test import Sniffer
-            from pocsuite3.thirdparty.scapy.utils import wrpcap
+            from pocsuite3.lib.utils.pcap_sniffer import Sniffer
+            from scapy.utils import wrpcap
             sniffer = Sniffer(urllib.parse.urlparse(target).hostname)
             if sniffer.use_pcap:
                 if not sniffer.is_admin:
@@ -107,7 +106,7 @@ def task_run():
                     conf.pcap = False
                 else:
                     sniffer.start()
-                    #let scapy start for a while
+                    # let scapy start for a while
                     time.sleep(1)
             else:
                 logger.warn("No libpcap is detected, and the poc will continue to execute without fetching the packet")
@@ -194,8 +193,12 @@ def task_run():
             sniffer.join(20)
             import urllib
             if not sniffer.is_alive():
-                logger.info("save pcap data in :{}".format(poc_name + time.strftime(" %Y%m%d%H ") + urllib.parse.urlparse(target).hostname+'.pcap'))
-                wrpcap(poc_name + time.strftime(" %Y%m%d%H ") + urllib.parse.urlparse(target).hostname+'.pcap', sniffer.pcap.results)
+                filename = (
+                    urllib.parse.urlparse(target).hostname +
+                    time.strftime('_%Y_%m_%d_%H%M%S.pcap')
+                )
+                logger.info(f"pcap data has been saved in: {filename}")
+                wrpcap(filename, sniffer.pcap.results)
             else:
                 logger.error("Thread terminates timeout. Failed to save pcap")
 
