@@ -4,6 +4,8 @@ import logging
 import os
 import re
 import socket
+import socks
+import importlib
 from queue import Queue
 from urllib.parse import urlsplit
 
@@ -13,6 +15,7 @@ from pocsuite3.lib.core.common import boldify_message, check_file, get_file_item
 from pocsuite3.lib.core.common import check_path, extract_cookies
 from pocsuite3.lib.core.common import get_local_ip, desensitization
 from pocsuite3.lib.core.common import single_time_warn_message
+from pocsuite3.lib.core.common import OrderedSet
 from pocsuite3.lib.core.convert import stdout_encode
 from pocsuite3.lib.core.data import conf, cmd_line_options
 from pocsuite3.lib.core.data import kb
@@ -32,8 +35,6 @@ from pocsuite3.lib.parse.configfile import config_file_parser
 from pocsuite3.lib.parse.rules import regex_rule
 from pocsuite3.lib.request.patch import patch_all
 from pocsuite3.modules.listener import start_listener
-from pocsuite3.thirdparty.oset.orderedset import OrderedSet
-from pocsuite3.thirdparty.pysocks import socks
 
 
 def _resolve_cross_references():
@@ -225,7 +226,7 @@ def _set_multiple_targets():
 
     if conf.dork:
         # enable plugin 'target_from_zoomeye' by default
-        if 'target_from_shodan' not in conf.plugins and 'target_from_fofa' not in conf.plugins:
+        if 'target_from_shodan' not in conf.plugins and 'target_from_fofa' not in conf.plugins and 'target_from_quake' not in conf.plugins:
             conf.plugins.append('target_from_zoomeye')
 
     if conf.dork_zoomeye:
@@ -240,6 +241,8 @@ def _set_multiple_targets():
     if conf.dork_fofa:
         conf.plugins.append('target_from_fofa')
 
+    if conf.dork_quake:
+        conf.plugins.append('target_from_quake')
 
 def _set_task_queue():
     if kb.registered_pocs and kb.targets:
@@ -314,7 +317,7 @@ def _set_user_pocs_path():
             paths.USER_POCS_PATH = conf.pocs_path
             for root, dirs, files in os.walk(paths.USER_POCS_PATH):
                 files = list(filter(lambda x: not x.startswith("__") and x.endswith(".py"), files))
-                conf.poc = [paths.USER_POCS_PATH + "\\" + f for f in files]
+                conf.poc = [os.path.join(paths.USER_POCS_PATH, f) for f in files]
         else:
             warm_msg = "User defined pocs path {0} is invalid".format(conf.pocs_path)
             logger.warn(warm_msg)
@@ -509,18 +512,20 @@ def _set_conf_attributes():
     conf.retry = 0
     conf.delay = 0
     conf.http_headers = {}
-    conf.agents = [DEFAULT_USER_AGENT]  # 数据源从插件加载的时候无默认值需要处理
+    conf.agents = [DEFAULT_USER_AGENT]  # When loading from the plug-in, if the data source has no default value, it needs to be processed
     conf.login_user = None
     conf.login_pass = None
     conf.shodan_token = None
     conf.fofa_user = None
     conf.fofa_token = None
+    conf.quake_token = None
     conf.censys_uid = None
     conf.censys_secret = None
     conf.dork = None
     conf.dork_zoomeye = None
     conf.dork_shodan = None
     conf.dork_fofa = None
+    conf.dork_quake = None
     conf.dork_censys = None
     conf.dork_b64 = False
     conf.max_page = 1
@@ -669,6 +674,28 @@ def _init_kb_comparison():
         kb.comparison = StatisticsComparison()
 
 
+def _init_target_from_poc_dork():
+    if len(kb.targets) > 0:
+        return
+
+    for poc_module, poc_class in kb.registered_pocs.items():
+        if not hasattr(poc_class, 'dork'):
+            continue
+        # find a available target source
+        target_source = ''
+        for i in ["zoomeye", "fofa", "shodan", "quake", "censys"]:
+            if i in poc_class.dork.keys():
+                target_source = i
+                break
+        # fetch target from target source, add it to kb.targets
+        conf.dork = poc_class.dork[target_source]
+        plugin_name = f'target_from_{target_source}'
+        importlib.import_module(f'pocsuite3.plugins.{plugin_name}')
+        for _, plugin in kb.plugins.targets.items():
+            if target_source in plugin.__class__.__name__.lower():
+                plugin.init()
+
+
 def init():
     """
     Set attributes into both configuration and knowledge base singletons
@@ -684,10 +711,11 @@ def init():
     update()
     _set_multiple_targets()
     _set_user_pocs_path()
-    _set_pocs_modules()  # poc module模块要在插件模块前，poc选项中某些参数调用了插件
+    _set_pocs_modules()  # The poc module module must be in front of the plug-in module, and some parameters in the poc option call the plug-in
     _set_plugins()
     _init_targets_plugins()
     _init_pocs_plugins()
+    _init_target_from_poc_dork()
     _set_task_queue()
     _init_results_plugins()
 
